Trait TryFuture

trait TryFuture: Future + private_try_future::Sealed

A convenience for futures that return Result values that includes a variety of adapters tailored to such futures.

Associated Types

type Ok

The type of successful values yielded by this future

type Error

The type of failures yielded by this future

Required Methods

fn try_poll(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<<Self as >::Ok, <Self as >::Error>>

Poll this TryFuture as if it were a Future.

This method is a stopgap for a compiler limitation that prevents us from directly inheriting from the Future trait; in the future it won't be needed.

Implementors