Trait Stream
trait Stream
A stream of values produced asynchronously.
If Future<Output = T> is an asynchronous version of T, then Stream<Item = T> is an asynchronous version of Iterator<Item = T>. A stream
represents a sequence of value-producing events that occur asynchronously to
the caller.
The trait is modeled after Future, but allows poll_next to be called
even after a value has been produced, yielding None once the stream has
been fully exhausted.
Associated Types
type ItemValues yielded by the stream.
Required Methods
fn poll_next(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<<Self as >::Item>>Attempt to pull out the next value of this stream, registering the current task for wakeup if the value is not yet available, and returning
Noneif the stream is exhausted.Return value
There are several possible return values, each indicating a distinct stream state:
-
Poll::Pendingmeans that this stream's next value is not ready yet. Implementations will ensure that the current task will be notified when the next value may be ready. -
Poll::Ready(Some(val))means that the stream has successfully produced a value,val, and may produce further values on subsequentpoll_nextcalls. -
Poll::Ready(None)means that the stream has terminated, andpoll_nextshould not be invoked again.
Panics
Once a stream has finished (returned
Ready(None)frompoll_next), calling itspoll_nextmethod again may panic, block forever, or cause other kinds of problems; theStreamtrait places no requirements on the effects of such a call. However, as thepoll_nextmethod is not markedunsafe, Rust's usual rules apply: calls must never cause undefined behavior (memory corruption, incorrect use ofunsafefunctions, or the like), regardless of the stream's state.If this is difficult to guard against then the
fuseadapter can be used to ensure thatpoll_nextalways returnsReady(None)in subsequent calls.-
Provided Methods
fn size_hint(self: &Self) -> (usize, Option<usize>)Returns the bounds on the remaining length of the stream.
Specifically,
size_hint()returns a tuple where the first element is the lower bound, and the second element is the upper bound.The second half of the tuple that is returned is an
Option<usize>. ANonehere means that either there is no known upper bound, or the upper bound is larger thanusize.Implementation notes
It is not enforced that a stream implementation yields the declared number of elements. A buggy stream may yield less than the lower bound or more than the upper bound of elements.
size_hint()is primarily intended to be used for optimizations such as reserving space for the elements of the stream, but must not be trusted to e.g., omit bounds checks in unsafe code. An incorrect implementation ofsize_hint()should not lead to memory safety violations.That said, the implementation should provide a correct estimation, because otherwise it would be a violation of the trait's protocol.
The default implementation returns
(0,None)which is correct for any stream.
Implementors
impl<S: ?Sized + Stream + Unpin> Stream for Box<S>impl<P> Stream for Pin<P>impl<S: ?Sized + Stream + Unpin> Stream for &mut Simpl<S: Stream> Stream for AssertUnwindSafe<S>