FusedFuture

Trait FusedFuture 

pub trait FusedFuture: Future {
    // Required method
    fn is_terminated(&self) -> bool;
}
A future which tracks whether or not the underlying future should no longer be polled.

is_terminated will return true if a future should no longer be polled. Usually, this state occurs after poll (or try_poll) returned Poll::Ready. However, is_terminated may also return true if a future has become inactive and can no longer make progress and should be ignored or dropped rather than being polled again.

Required Methods

fn is_terminated(&self) -> bool

Returns true if the underlying future should no longer be polled.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<F: FusedFuture + ?Sized + Unpin> FusedFuture for &mut F

Source

impl<F: FusedFuture + ?Sized + Unpin> FusedFuture for Box<F>

Source

impl<F: FusedFuture> FusedFuture for AssertUnwindSafe<F>

Available on crate feature std only.
Source

impl<P> FusedFuture for Pin<P>
where P: DerefMut + Unpin, P::Target: FusedFuture,

Implementors