Type Alias BoxStream

type BoxStream = Pin<Box<dyn Stream<Item = T> + Send + 'a>>

An owned dynamically typed Stream for use in cases where you can't statically type your result or need to add some indirection.

This type is often created by the boxed method on StreamExt. See its documentation for more.